@@ -3,18 +3,20 @@ package OptionTestApp;
 use strict;
 use warnings;
 
-BEGIN {
+BEGIN
+{
     my $moodel = $ENV{WHICH_MOODEL} || "Moo";
-    eval "use $moodel;"; $@ and die $@;
+    eval "use $moodel;";
+    $@ and die $@;
     $moodel->import;
 }
 use MooX::Cmd execute_from_new => undef;
 use MooX::Options;
 
 option in_doubt => (
-    is => "ro",
+    is          => "ro",
     negativable => 1,
-    doc => "in doubt?",
+    doc         => "in doubt?",
 );
 
 sub execute { @_ }
