@@ -1,8 +1,10 @@
 package ThirdTestApp::Cmd::Foo;
 
-BEGIN {
+BEGIN
+{
     my $moodel = $ENV{WHICH_MOODEL} || "Moo";
-    eval "use $moodel;"; $@ and die $@;
+    eval "use $moodel;";
+    $@ and die $@;
     $moodel->import;
 }
 
